Args

Struct Args 

pub struct Args {
Show 81 fields pub paths: Vec<PathBuf>, pub help: Option<bool>, pub all: bool, pub almost_all: bool, pub long: bool, pub one_per_line: bool, pub columns: bool, pub commas: bool, pub human_readable: bool, pub si: bool, pub recursive: bool, pub reverse: bool, pub sort_time: bool, pub sort_size: bool, pub sort_extension: bool, pub sort_version: bool, pub sort_none: bool, pub sort: Option<String>, pub time: Option<String>, pub access_time: bool, pub change_time: bool, pub color: ColorArg, pub json: bool, pub csv: bool, pub tsv: bool, pub tree: bool, pub gnu: bool, pub icons: IconsArg, pub classify: bool, pub indicator_slash: bool, pub file_type: bool, pub indicator_style: Option<String>, pub dirs_first: bool, pub directory: bool, pub ignore_backups: bool, pub ignore: Vec<String>, pub hide: Vec<String>, pub dereference: bool, pub dereference_command_line: bool, pub dereference_command_line_symlink_to_dir: bool, pub no_owner: bool, pub no_group_long: bool, pub no_group: bool, pub numeric_uid_gid: bool, pub inode: bool, pub size_blocks: bool, pub kibibytes: bool, pub block_size: Option<String>, pub full_time: bool, pub time_style: Option<String>, pub hide_control_chars: bool, pub show_control_chars: bool, pub escape: bool, pub quote_name: bool, pub literal: bool, pub quoting_style: Option<String>, pub across: bool, pub unsorted_all: bool, pub format: Option<String>, pub tabsize: Option<usize>, pub width: Option<usize>, pub context: bool, pub zero: bool, pub dired: bool, pub author: bool, pub hyperlink: Option<String>, pub max_depth: Option<usize>, pub git: bool, pub config: Option<PathBuf>, pub browse: bool, pub ignore_files: bool, pub no_ignore: bool, pub archive: bool, pub threads: usize, pub profile: bool, pub io_uring: bool, pub generate_completions: Option<Shell>, pub generate_man: bool, pub update: bool, pub check_update: bool, pub list_plugins: bool,
}
f00 — a modern, friendly directory lister

Fields

paths: Vec<PathBuf>

Paths to list (default: current directory)

help: Option<bool>

Print help

all: bool

Do not ignore entries starting with .

almost_all: bool

Do not list implied . and .. (show other hidden files)

long: bool

Use a long listing format

one_per_line: bool

List one file per line

columns: bool

List entries by columns

commas: bool

Fill width with a comma separated list of entries

human_readable: bool

With -l and -s, print sizes like 1K 234M 2G etc.

si: bool

Likewise, but use powers of 1000 not 1024

recursive: bool

List subdirectories recursively

reverse: bool

Reverse sort order

sort_time: bool

Sort by time, newest first

sort_size: bool

Sort by file size, largest first

sort_extension: bool

Sort alphabetically by entry extension

sort_version: bool

Natural sort of (version) numbers within text (strverscmp)

sort_none: bool

Do not sort; list entries in directory order

sort: Option<String>

Sort by WORD (name, size, time, extension, version, none)

time: Option<String>

Use time WORD for display/sort: mtime, atime, ctime, birth

access_time: bool

Sort by, and show, access time

change_time: bool

Sort by, and show, ctime (status change) when possible

color: ColorArg

Colorize output

json: bool

Emit structured JSON (-j is free: GNU ls has no short -j)

csv: bool

Emit CSV

tsv: bool

Emit TSV

tree: bool

Show entries as a tree

gnu: bool

Stricter GNU ls-compatible behavior

icons: IconsArg

Show file icons (auto/always/never; default: auto — TTY only, off under –gnu)

classify: bool

Append indicator (one of */=@|) to entries

indicator_slash: bool

Append / indicator to directories

file_type: bool

Like -F, except do not append ‘*’

indicator_style: Option<String>

Append indicator with style WORD: none, slash, file-type, classify

dirs_first: bool

Group directories before files

directory: bool

List directories themselves, not their contents

ignore_backups: bool

Do not list implied entries ending with ~

ignore: Vec<String>

Do not list implied entries matching shell PATTERN (repeatable)

hide: Vec<String>

Do not list implied entries matching shell PATTERN (unless -a/-A)

dereference: bool

When showing file information for a symbolic link, show info for the file it references

dereference_command_line: bool

Follow symbolic links listed on the command line

dereference_command_line_symlink_to_dir: bool

Follow each command line symbolic link that points to a directory

no_owner: bool

Like -l, but do not list owner

no_group_long: bool

Like -l, but do not list group information

no_group: bool

In a long listing, don’t print group names

numeric_uid_gid: bool

Like -l, but list numeric user and group IDs

inode: bool

Print the index number of each file

size_blocks: bool

Print the allocated size of each file, in blocks

kibibytes: bool

Default to 1024-byte blocks for filesystem disk usage (-s)

block_size: Option<String>

Scale sizes by SIZE before printing (e.g. 1K, 1M, KB, MB)

full_time: bool

Like -l –time-style=full-iso

time_style: Option<String>

Time/date format with -l; also TIME_STYLE env

hide_control_chars: bool

Print ? instead of nongraphic characters

show_control_chars: bool

Show nongraphic characters as-is (the default unless -q)

escape: bool

Print C-style escapes for nongraphic characters

quote_name: bool

Enclose entry names in double quotes

literal: bool

Print entry names without quoting

quoting_style: Option<String>

Use quoting style WORD for entry names

across: bool

List entries by lines instead of by columns (row-major)

unsorted_all: bool

Same as -a -U (and disable decorations in GNU mode)

format: Option<String>

Across/commas/long/single-column/vertical

tabsize: Option<usize>

Assume tab stops at each COLS instead of 8 (stored for layout)

width: Option<usize>

Set output width to COLS; 0 means no limit

context: bool

Print any security context of each file (SELinux)

zero: bool

End each output line with NUL, not newline

dired: bool

Generate output designed for Emacs’ dired mode

author: bool

With -l, print the author of each file

hyperlink: Option<String>

Hyperlink file names (auto/always/never)

max_depth: Option<usize>

Maximum recursion depth (with -R / –tree)

git: bool

Annotate with git status (requires feature git)

config: Option<PathBuf>

Path to TOML config file (overrides default search path)

browse: bool

Interactive TUI directory browser (requires feature tui)

ignore_files: bool

Honor .gitignore / .f00ignore when listing

no_ignore: bool

Do not honor ignore files (overrides –ignore-files)

archive: bool

Auto-list zip/tar archives as directories (default: true; off under –gnu)

threads: usize

Parallel metadata threads: 0 = auto (rayon default), 1 = serial, N>1 = fixed pool

profile: bool

Print phase timing breakdown to stderr (readdir/stat/sort/format/total)

io_uring: bool

Use io_uring batch metadata when built with --features io-uring (Linux)

generate_completions: Option<Shell>

Generate shell completions to stdout and exit (bash, zsh, fish, powershell, elvish)

generate_man: bool

Generate a man page to stdout and exit

update: bool

Update f00 from the latest GitHub Release (checksum verified)

check_update: bool

Check whether a newer release is available (no mutation); exit 1 if behind

list_plugins: bool

List loaded plugins (requires feature plugins)

Implementations

Source

impl Args

pub fn test_default() -> Self

Minimal args for tests (all flags default/off).